summaryrefslogtreecommitdiff
path: root/src/node/hooks/express/webaccess.js
diff options
context:
space:
mode:
Diffstat (limited to 'src/node/hooks/express/webaccess.js')
-rw-r--r--src/node/hooks/express/webaccess.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/node/hooks/express/webaccess.js b/src/node/hooks/express/webaccess.js
index 41bf3880..50323ef6 100644
--- a/src/node/hooks/express/webaccess.js
+++ b/src/node/hooks/express/webaccess.js
@@ -15,8 +15,8 @@ exports.basicAuth = function (req, res, next) {
}
var authorize = function (cb) {
- // Do not require auth for static paths...this could be a bit brittle
- if (req.path.match(/^\/(static|javascripts|pluginfw)/)) return cb(true);
+ // Do not require auth for static paths and the API...this could be a bit brittle
+ if (req.path.match(/^\/(static|javascripts|pluginfw|api)/)) return cb(true);
if (req.path.indexOf('/admin') != 0) {
if (!settings.requireAuthentication) return cb(true);